@@ -24,7 +24,7 @@
 
 
 __project__ = "pigit"
-__version__ = "1.3.4"
+__version__ = "1.3.6"
 __url__ = "https://github.com/zlj-zz/pigit.git"
 __uri__ = __url__
 
@@ -32,7 +32,7 @@ __author__ = "Zachary Zhang"
 __email__ = "zlj19971222@outlook.com"
 
 __license__ = "MIT"
-__copyright__ = "Copyright (c) 2021 Zachary"
+__copyright__ = "Copyright (c) 2021-2022 Zachary"
 
 
 import os
@@ -43,7 +43,7 @@ from shutil import get_terminal_size
 from typing import Optional, Union
 
 from .log import setup_logging
-from .common import Color, render_str, get_current_shell
+from .common import Color, render_str, get_current_shell, traceback_info
 from .gitinfo import (
     Git_Version,
     REPOSITORY_PATH,
@@ -82,22 +82,22 @@ if IS_WIN:
     USER_HOME = os.environ["USERPROFILE"]
     PIGIT_HOME = os.path.join(USER_HOME, __project__)
 else:
+    # ~/.config/pigit
     USER_HOME = os.environ["HOME"]
     PIGIT_HOME = os.path.join(USER_HOME, ".config", __project__)
 
-LOG_PATH: str = PIGIT_HOME + "/log/{0}.log".format(__project__)
-CONFIG_PATH: str = PIGIT_HOME + "/pigit.conf"
-COUNTER_PATH: str = PIGIT_HOME + "/Counter"
+LOG_FILE_PATH: str = PIGIT_HOME + "/log/{0}.log".format(__project__)
+CONFIG_FILE_PATH: str = PIGIT_HOME + "/pigit.conf"
+COUNTER_DIR_PATH: str = PIGIT_HOME + "/Counter"
+EXTRA_CMD_FILE_PATH: str = PIGIT_HOME + "/extra_cmds.py"
 
 
 #####################################################################
 # Configuration.                                                    #
 #####################################################################
-CONFIG = Config(path=CONFIG_PATH, current_version=__version__)
-if CONFIG.warnings:
-    for warning in CONFIG.warnings:
-        print(warning)
-    CONFIG.warnings = []
+CONFIG = Config(
+    path=CONFIG_FILE_PATH, version=__version__, auto_load=True
+).output_warnings()
 
 
 #####################################################################
@@ -128,7 +128,9 @@ def introduce() -> None:
     # Print package path.
     print(
         render_str(
-            "b`Local path`: u`{}`<sky_blue>\n".format(__file__.replace("./", ""))
+            "b`Local path`: u`{}`<sky_blue>\n".format(
+                os.path.dirname(__file__.replace("./", ""))
+            )
         )
     )
 
@@ -136,20 +138,19 @@ def introduce() -> None:
     print(
         render_str(
             "b`Description:`\n"
-            "  Terminal tool, help you use git more simple."
-            " Support Linux, MacOS and Windows.\n"
+            "  Terminal tool, help you use git more simple. Support Linux, MacOS and Windows.\n"
             "  It use short command to replace the original command, like: \n"
-            "  ``pigit ws``<ok> -> ``git status --short``<ok>,"
-            " ``pigit b``<ok> -> ``git branch``<ok>.\n"
-            "  Also you use ``pigit -s``<ok> to get the all short command,"
-            " have fun and good lucky.\n"
-            f"  The open source path on github: u`{__url__}`<sky_blue>"
+            "  ``pigit ws``<ok> -> ``git status --short``<ok>, ``pigit b``<ok> -> ``git branch``<ok>.\n"
+            "  Also you use ``pigit -s``<ok> to get the all short command, have fun and good lucky.\n"
+            f"  The open source path on github: u`{__url__}`<sky_blue>\n\n"
+            "You can use `-h`<ok> or `--help`<ok> to get help and more usage."
         )
     )
 
-    print(
-        render_str("\nYou can use `-h`<ok> or `--help`<ok> to get help and more usage.")
-    )
+
+def print_alias(alias_name: str):
+    alias = f"alias {alias_name}=pigit"
+    print(alias)
 
 
 def get_extra_cmds() -> dict:
@@ -163,18 +164,14 @@ def get_extra_cmds() -> dict:
     """
     import imp
 
-    extra_cmd_path: str = PIGIT_HOME + "/extra_cmds.py"
+    extra_cmd_path = EXTRA_CMD_FILE_PATH
     extra_cmds = {}
 
     if os.path.isfile(extra_cmd_path):
         try:
             extra_cmd = imp.load_source("extra_cmd", extra_cmd_path)
         except Exception as e:
-            Log.error(
-                "Can't load file '{0}';{1};{2}".format(
-                    extra_cmd_path, str(e), str(e.__traceback__)
-                )
-            )
+            Log.error(traceback_info(f"Can't load file '{extra_cmd_path}'."))
         else:
             try:
                 extra_cmds = extra_cmd.extra_cmds  # type: ignore
@@ -421,6 +418,12 @@ class Parser(object):
             action="store_true",
             help="List all command types and exit.",
         )
+        p.add_argument(
+            "--alias",
+            nargs="?",
+            const="g",
+            help="print PIGIT alias handle, custom alias name.",
+        )
         p.add_argument(
             "-d",
             "--debug",
@@ -512,6 +515,9 @@ class Parser(object):
                 show_summary=CONFIG.repository_show_summary,
             )
 
+            if known_args.alias:
+                return print_alias(known_args.alias)
+
             if known_args.complete:
                 # Generate competion vars dict.
                 completion_vars = {
@@ -542,7 +548,7 @@ class Parser(object):
                 CodeCounter(
                     count_path=path,
                     use_ignore=CONFIG.codecounter_use_gitignore,
-                    result_saved_path=COUNTER_PATH,
+                    result_saved_path=COUNTER_DIR_PATH,
                     result_format=CONFIG.codecounter_result_format,
                     use_icon=CONFIG.codecounter_show_icon,
                 ).count_and_format_print(
@@ -609,7 +615,7 @@ def main(custom_commands: Optional[list] = None):
     stdargs, extra_unknown = parser.parse()
 
     # Setup log handle.
-    log_file = LOG_PATH if stdargs.out_log or CONFIG.stream_output_log else None
+    log_file = LOG_FILE_PATH if stdargs.out_log or CONFIG.stream_output_log else None
     setup_logging(debug=stdargs.debug or CONFIG.debug_mode, log_file=log_file)
 
     # Process result.
